@@ -65,6 +65,8 @@ public:
     void setFixedPrecision(int precision);
     void setPrecision(int precision);
     void setText(const QString &string);
+    void setFont(const QFont &font);
+    const QFont &baseFont() const;
     QString formatDecimalNumber(QString string);
     QString groupDigits(const QString &displayString, int numDigits);
     QString text() const;
@@ -89,11 +91,13 @@ Q_SIGNALS:
 protected:
     void mousePressEvent(QMouseEvent *) override;
     void paintEvent(QPaintEvent *p) override;
+    void resizeEvent(QResizeEvent* event) override;
 
 private:
     bool changeSign();
     void invertColors();
     void initStyleOption(QStyleOptionFrame *option) const;
+    void updateFont();
 
 private Q_SLOTS:
     void slotSelectionTimedOut();
@@ -118,6 +122,8 @@ private:
 
     KNumber display_amount_;
 
+    QFont baseFont_;
+
     QVector<KNumber> history_list_;
     int history_index_;
 
